<template>
  <basic-container>
    <avue-crud ref="crud"
               v-model="form"
               :data="data"
               :option="option"
               :page.sync="page"
               @on-load="getList"
               @row-update="rowUpdate"
               @row-save="rowSave"
               @row-del="rowDel"
               @refresh-change="refreshChange"
               @search-reset="searchChange"
               @search-change="searchChange">
      <template slot="menuLeft">
        <el-tooltip class="item" effect="dark" content="查找版本规则使用范围" placement="top">
          <el-button size="small"
                     plain
                     type="primary"
                     icon="el-icon-zoom-in"
                     @click="handleSearch">查看使用范围
          </el-button>
        </el-tooltip>
      </template>>
    </avue-crud>
    <el-dialog title="查看使用范围"
               append-to-body
               :visible.sync="packageSearchBox"
               width="1200px">
      <versionpackage></versionpackage>
    </el-dialog>
  </basic-container>

</template>

<script>
import { getPage,add,update,remove } from '../../api/omd/revisionRule';
export default {
  name: "Version",
  data(){
    return {
      //查看使用范围
      packageSearchBox:false,
      //分页数据
      page: {
        pageSize: 10,
        currentPage: 1,
        total: 100
      },
      data:[
      ],
      form:{},
      option:{
        headerAlign:'center',
        align: 'center',
        border: true,
        index: true,
        searchMenuSpan:5,
        column:[
          {
            label:'英文名称',
            prop: 'id'
          },
          {
            label:"中文名称",
            prop:"name",
            search:true,
          },
          {
            label:"跳跃字符",
            prop: "skipCode"
          },
          {
            label: "初始值",
            prop:"startCode"
          },
          {
            label: "步长",
            prop: "serialStep"
          },
          {
            label: "前缀",
            prop:"prefixCode"
          },
          {
            label: "后缀",
            prop: "suffixCode"
          },
          {
            label: "描述",
            prop:"description",
            type:"textarea"
          }
        ]
      }
    }
  },
  methods:{
    handleSearch(){
      this.packageSearchBox=true
    },
    getList() {
      this.loading = true;
      getPage(this.page.currentPage,this.page.pageSize,this.params).then(res => {
        const data = res.data.data
        this.loading = false;
        this.page.total = data.total;
        this.data = data.records;
      })
    },
    rowSave(row, done, loading) {
      add(row).then(() => {
        this.$message.success('新增成功')
        done();
        this.getList();
      }).catch(() => {
        loading()
      })
    },
    rowUpdate(row, index, done, loading) {
      update(row).then(() => {
        this.$message.success('修改成功')
        done()
        this.getList();
      }).catch(() => {
        loading()
      })
    },
    rowDel(row) {
      this.$confirm('此操作将永久删除, 是否继续?', '提示', {
        confirmButtonText: '确定',
        cancelButtonText: '取消',
        type: 'warning'
      }).then(() => {
        console.log(row);
        return remove({oid : row.oid})
      }).then(() => {
        this.$message.success('删除成功')
        this.getList();
      })
    },
    searchChange(params, done) {
      if (done) done();
      this.params = params;
      this.page.currentPage = 1;
      this.getList();
      this.$message.success('搜索成功')
    },
    refreshChange() {
      this.getList();
      this.$message.success('刷新成功')
    }
  }
}
</script>

<style scoped>

</style>
